@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #ifndef GNUMERIC_MS_OFFICE_ESCHER_H
 #define GNUMERIC_MS_OFFICE_ESCHER_H
 
@@ -12,17 +13,19 @@
  **/
 #include "ms-excel-read.h"
 #include "ms-container.h"
+#include "ms-obj.h"
 
-struct _MSEscherBlip
-{
+struct _MSEscherBlip {
 	char const   *type;
 	guint8       *data;
 	guint32	      data_len;
 	gboolean      needs_free;
 };
 
-void ms_escher_parse     (BiffQuery  *q, MSContainer *container);
-void ms_escher_blip_free (MSEscherBlip *blip);
+MSObjAttrBag *ms_escher_parse (BiffQuery  *q, MSContainer *container,
+			       gboolean return_attrs);
+
+void	      ms_escher_blip_free (MSEscherBlip *blip);
 
 #if 0
 typedef struct _MSEscherWriter MSEscherWriter;
