@@ -23,7 +23,6 @@
 #define EX_SETROW(p,d)    (GSF_LE_SET_GUINT16(p + 0, d))
 #define EX_SETCOL(p,d)    (GSF_LE_SET_GUINT16(p + 2, d))
 #define EX_SETXF(p,d)     (GSF_LE_SET_GUINT16(p + 4, d))
-#define EX_SETSTRLEN(p,d) (GSF_LE_SET_GUINT16(p + 6, d))
 
 /* Version info types as found in various Biff records */
 typedef enum { MS_BIFF_TYPE_Workbook=0, MS_BIFF_TYPE_VBModule=1, MS_BIFF_TYPE_Worksheet=2,
@@ -66,13 +65,6 @@ typedef enum {	/* Vertical alignment */
 	MS_BIFF_V_A_JUSTIFY = 3
 } MsBiffVAlign;
 
-typedef enum {	/* Text orientation */
-	MS_BIFF_O_HORIZ         = 0,
-	MS_BIFF_O_VERT_HORIZ = 1,
-	MS_BIFF_O_VERT_VERT  = 2,
-	MS_BIFF_O_VERT_VERT2 = 3
-} MsBiffOrient;
-
 typedef enum { /* Differences to parent styles */
 	MS_BIFF_D_FORMAT_BIT = 10,
 	MS_BIFF_D_FONT_BIT   = 11,
