@@ -4,7 +4,7 @@
 #include "value.h"
 #include <gbrun/libgbrun.h>
 
-GBValue *value_to_gb (Value *val);
-Value   *gb_to_value (GBValue *v);
+GBValue  *value_to_gb (GnmValue *val);
+GnmValue *gb_to_value (GBValue  *val);
 
 #endif /* EXCEL_GB_COMMON_H */
