@@ -1,3 +1,6 @@
+#ifndef GNUMERIC_PLUGIN_GUILE_SMOB_VALUE_H
+#define GNUMERIC_PLUGIN_GUILE_SMOB_VALUE_H
+
 /* -*- mode: c; c-basic-offset: 8 -*- */
 
 /*
@@ -27,6 +30,7 @@
 
 void init_value_type (void);
 
-SCM make_new_smob (Value *);
-Value *get_value_from_smob (SCM);
+SCM make_new_smob (GnmValue *);
+GnmValue *get_value_from_smob (SCM);
 
+#endif
