@@ -21,8 +21,9 @@
 
 #include <gnumeric-config.h>
 #include <goffice/graph/gog-label.h>
-#include <goffice/graph/gog-styled-object.h>
+#include <goffice/graph/gog-outlined-object.h>
 #include <goffice/graph/gog-style.h>
+#include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-data-set.h>
@@ -33,9 +34,12 @@
 #include <src/gnumeric-i18n.h>
 
 #include <gsf/gsf-impl-utils.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkbox.h>
 
 struct _GogLabel {
-	GogStyledObject	base;
+	GogOutlinedObject	base;
 
 	GogDatasetElement text;
 	gboolean	  allow_markup;
@@ -93,8 +97,9 @@ gog_label_finalize (GObject *obj)
 }
 
 static gpointer
-gog_label_editor (GogObject *gobj, GogDataAllocator *dalloc, CommandContext *cc)
+gog_label_editor (GogObject *gobj, GogDataAllocator *dalloc, GnmCmdContext *cc)
 {
+	static guint label_pref_page = 0;
 	GtkWidget *notebook = gtk_notebook_new ();
 	GtkWidget *hbox = gtk_hbox_new (FALSE, 5);
 
@@ -106,15 +111,17 @@ gog_label_editor (GogObject *gobj, GogDataAllocator *dalloc, CommandContext *cc)
 	gtk_widget_show_all (hbox);
 	gtk_notebook_prepend_page (GTK_NOTEBOOK (notebook), hbox,
 		gtk_label_new (_("Data")));
-	gog_style_editor (gobj, cc, notebook,
-		GOG_STYLE_OUTLINE | GOG_STYLE_FILL | GOG_STYLE_FONT);
+	gog_style_editor (GOG_STYLED_OBJECT (gobj), cc, notebook);
+	gog_style_handle_notebook (notebook, &label_pref_page);
 	return notebook;
 }
 
-static unsigned
-gog_label_interesting_fields (GogStyledObject *obj)
+static void
+gog_label_init_style (GogStyledObject *gso, GogStyle *style)
 {
-	return GOG_STYLE_OUTLINE | GOG_STYLE_FILL | GOG_STYLE_FONT;
+	style->interesting_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL | GOG_STYLE_FONT;
+	gog_theme_init_style (gog_object_get_theme (GOG_OBJECT (gso)),
+		style, GOG_OBJECT (gso), 0);
 }
 
 static void
@@ -135,7 +142,7 @@ gog_label_class_init (GogLabelClass *klass)
 
 	gog_klass->editor	= gog_label_editor;
 	gog_klass->view_type	= gog_label_view_get_type ();
-	style_klass->interesting_fields = gog_label_interesting_fields;
+	style_klass->init_style = gog_label_init_style;
 }
 
 static void
@@ -167,72 +174,50 @@ gog_label_dataset_init (GogDatasetClass *iface)
 
 GSF_CLASS_FULL (GogLabel, gog_label,
 		gog_label_class_init, NULL,
-		GOG_STYLED_OBJECT_TYPE, 0,
+		GOG_OUTLINED_OBJECT_TYPE, 0,
 		GSF_INTERFACE (gog_label_dataset_init, GOG_DATASET_TYPE))
 
 /************************************************************************/
 
-typedef GogView		GogLabelView;
-typedef GogViewClass	GogLabelViewClass;
+typedef GogOutlinedView		GogLabelView;
+typedef GogOutlinedViewClass	GogLabelViewClass;
 
 #define GOG_LABEL_VIEW_TYPE	(gog_label_view_get_type ())
 #define GOG_LABEL_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LABEL_VIEW_TYPE, GogLabelView))
 #define IS_GOG_LABEL_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LABEL_VIEW_TYPE))
 
 static void
-gog_label_view_size_request (GogView *view, GogViewRequisition *req)
+gog_label_view_size_request (GogView *v, GogViewRequisition *req)
 {
-	GogLabel *label = GOG_LABEL (view->model);
-	double outline = gog_renderer_line_size (
-		view->renderer, label->base.style->outline.width);
+	GogLabel *l = GOG_LABEL (v->model);
 
-	req->w = req->h = 1.;
-	if (label->text.data != NULL) {
-		char const *text = go_data_scalar_get_str (GO_DATA_SCALAR (label->text.data));
+	req->w = req->h = 0.;
+	if (l->text.data != NULL) {
+		char const *text = go_data_scalar_get_str (GO_DATA_SCALAR (l->text.data));
 		if (text != NULL) {
-			gog_renderer_push_style (view->renderer, label->base.style);
-			gog_renderer_measure_text (view->renderer, text, req);
-			gog_renderer_pop_style (view->renderer);
+			gog_renderer_push_style (v->renderer, l->base.base.style);
+			gog_renderer_measure_text (v->renderer, text, req);
+			gog_renderer_pop_style (v->renderer);
 		}
 	}
-	req->w += outline * 2;
-	req->h += outline * 2;
-}
-
-static void
-gog_label_view_size_allocate (GogView *view, GogViewAllocation const *a)
-{
-	GogLabel *label = GOG_LABEL (view->model);
-	GogViewAllocation res = *a;
-	double outline = gog_renderer_line_size (
-		view->renderer, label->base.style->outline.width);
-
-	res.x += outline;
-	res.y += outline;
-	res.w -= outline * 2.;
-	res.h -= outline * 2.;
-	(lview_parent_klass->size_allocate) (view, &res);
+	lview_parent_klass->size_request (v, req);
 }
 
 static void
 gog_label_view_render (GogView *view, GogViewAllocation const *bbox)
 {
-	GogLabel *label = GOG_LABEL (view->model);
+	GogLabel *l = GOG_LABEL (view->model);
 
-	gog_renderer_push_style (view->renderer, label->base.style);
-	gog_renderer_draw_rectangle (view->renderer, &view->allocation);
+	(lview_parent_klass->render) (view, bbox);
 
-	if (label->text.data != NULL) {
-		char const *text = go_data_scalar_get_str (GO_DATA_SCALAR (label->text.data));
-		if (text != NULL) {
-			ArtPoint  point;
-			point.x = view->residual.x;
-			point.y = view->residual.y;
-			gog_renderer_draw_text (view->renderer, &point, GTK_ANCHOR_NW, text, NULL);
-		}
+	gog_renderer_push_style (view->renderer, l->base.base.style);
+	if (l->text.data != NULL) {
+		char const *text = go_data_scalar_get_str (GO_DATA_SCALAR (l->text.data));
+		if (text != NULL)
+			gog_renderer_draw_text (view->renderer, text,
+				&view->residual, GTK_ANCHOR_NW, NULL);
 	}
 	gog_renderer_pop_style (view->renderer);
-	(lview_parent_klass->render) (view, bbox);
 }
 
 static void
@@ -242,10 +227,9 @@ gog_label_view_class_init (GogLabelViewClass *gview_klass)
 
 	lview_parent_klass = g_type_class_peek_parent (gview_klass);
 	view_klass->size_request    = gog_label_view_size_request;
-	view_klass->size_allocate   = gog_label_view_size_allocate;
 	view_klass->render	    = gog_label_view_render;
 }
 
 static GSF_CLASS (GogLabelView, gog_label_view,
 	   gog_label_view_class_init, NULL,
-	   GOG_VIEW_TYPE)
+	   GOG_OUTLINED_VIEW_TYPE)
