@@ -21,25 +21,28 @@
 
 #include <gnumeric-config.h>
 #include <goffice/graph/gog-legend.h>
-#include <goffice/graph/gog-styled-object.h>
+#include <goffice/graph/gog-outlined-object.h>
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
 #include <goffice/graph/gog-chart.h>
 #include <goffice/graph/gog-style.h>
+#include <goffice/graph/gog-theme.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-units.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <src/gnumeric-i18n.h>
 
+#include <gtk/gtknotebook.h>
+
 struct _GogLegend {
-	GogStyledObject	base;
+	GogOutlinedObject base;
 
 	double	 swatch_size_pts;
 	double	 swatch_padding_pts;
 	gulong	 chart_cardinality_handle;
 	gulong	 chart_child_name_changed_handle;
-	int	 cached_count;
+	unsigned cached_count;
 	gboolean names_changed;
 };
 
@@ -141,9 +144,10 @@ static void
 gog_legend_update (GogObject *obj)
 {
 	GogLegend *legend = GOG_LEGEND (obj);
-	int i = gog_chart_get_cardinality (GOG_CHART (obj->parent));
-	if (legend->cached_count != i)
-		legend->cached_count = i;
+	unsigned visible;
+	gog_chart_get_cardinality (GOG_CHART (obj->parent), NULL, &visible);
+	if (legend->cached_count != visible)
+		legend->cached_count = visible;
 	else if (!legend->names_changed)
 		return;
 	legend->names_changed = FALSE;
@@ -151,15 +155,22 @@ gog_legend_update (GogObject *obj)
 }
 
 static gpointer
-gog_legend_editor (GogObject *gobj, GogDataAllocator *dalloc, CommandContext *cc)
+gog_legend_editor (GogObject *gobj, GogDataAllocator *dalloc, GnmCmdContext *cc)
 {
-	return gog_style_editor	(gobj, cc, NULL, GOG_STYLE_OUTLINE | GOG_STYLE_FILL);
+	static guint legend_pref_page = 0;
+	GtkWidget *notebook = gtk_notebook_new ();
+
+	gog_style_editor (GOG_STYLED_OBJECT (gobj), cc, notebook);
+	gog_style_handle_notebook (notebook, &legend_pref_page);
+	return notebook;
 }
 
-static unsigned
-gog_legend_interesting_fields (GogStyledObject *obj)
+static void
+gog_legend_init_style (GogStyledObject *gso, GogStyle *style)
 {
-	return GOG_STYLE_OUTLINE | GOG_STYLE_FILL | GOG_STYLE_FONT;
+	style->interesting_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL | GOG_STYLE_FONT;
+	gog_theme_init_style (gog_object_get_theme (GOG_OBJECT (gso)),
+		style, GOG_OBJECT (gso), 0);
 }
 
 static void
@@ -183,7 +194,7 @@ gog_legend_class_init (GogLegendClass *klass)
 	gog_klass->update	  = gog_legend_update;
 	gog_klass->editor	  = gog_legend_editor;
 	gog_klass->view_type	  = gog_legend_view_get_type ();
-	style_klass->interesting_fields = gog_legend_interesting_fields;
+	style_klass->init_style	  = gog_legend_init_style;
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
 
 	g_object_class_install_property (gobject_klass, LEGEND_SWATCH_SIZE_PTS,
@@ -206,14 +217,14 @@ gog_legend_init (GogLegend *legend)
 
 GSF_CLASS (GogLegend, gog_legend,
 	   gog_legend_class_init, gog_legend_init,
-	   GOG_STYLED_OBJECT_TYPE)
+	   GOG_OUTLINED_OBJECT_TYPE)
 
 typedef struct {
-	GogView		base;
+	GogOutlinedView	base;
 	double		line_height;
 	gboolean	uses_lines;
 } GogLegendView;
-typedef GogViewClass	GogLegendViewClass;
+typedef GogOutlinedViewClass	GogLegendViewClass;
 
 #define GOG_LEGEND_VIEW_TYPE	(gog_legend_view_get_type ())
 #define GOG_LEGEND_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LEGEND_VIEW_TYPE, GogLegendView))
@@ -253,8 +264,6 @@ gog_legend_view_size_request (GogView *v, GogViewRequisition *avail)
 	GogLegend *l = GOG_LEGEND (v->model);
 	double pad_y = gog_renderer_pt2r_y (
 		v->renderer, l->swatch_padding_pts);
-	double outline = gog_renderer_line_size (
-		v->renderer, l->base.style->outline.width);
 	unsigned n, mult = 1;
 
 #warning TODO : make this smarter (multiple columns and shrinking text)
@@ -262,7 +271,8 @@ gog_legend_view_size_request (GogView *v, GogViewRequisition *avail)
 	dat.maximum.w = 0.;
 	dat.maximum.h = gog_renderer_pt2r_y (v->renderer, l->swatch_size_pts);
 	dat.uses_lines = FALSE;
-	gog_chart_foreach_elem (chart, (GogEnumFunc) cb_size_elements, &dat);
+	gog_chart_foreach_elem (chart, TRUE,
+		(GogEnumFunc) cb_size_elements, &dat);
 	((GogLegendView *)v)->line_height = dat.maximum.h;
 	((GogLegendView *)v)->uses_lines = dat.uses_lines;
 
@@ -272,7 +282,7 @@ gog_legend_view_size_request (GogView *v, GogViewRequisition *avail)
 	/* 1/2 between swatch and label */
 	res.w = dat.maximum.w + gog_renderer_pt2r_x (v->renderer,
 		mult * l->swatch_size_pts + .5 * l->swatch_padding_pts);
-	n = gog_chart_get_cardinality (chart);
+	gog_chart_get_cardinality (chart, NULL, &n);
 	res.h = n * dat.maximum.h;
 	if (n > 1)
 		res.h += (n-1) * pad_y; /* between lines, not top or bottom */
@@ -280,32 +290,7 @@ gog_legend_view_size_request (GogView *v, GogViewRequisition *avail)
 	gog_view_size_child_request (v, avail, &res);
 	avail->w = res.w;
 	avail->h = res.h;
-	if (outline > 0) {
-		double pad_x = gog_renderer_pt2r_x (v->renderer, l->swatch_padding_pts);
-		avail->w += outline * 2 + pad_x;
-		avail->h += outline * 2 + pad_y;
-	}
-}
-
-static void
-gog_legend_view_size_allocate (GogView *v, GogViewAllocation const *a)
-{
-	GogLegend *l = GOG_LEGEND (v->model);
-	GogViewAllocation res = *a;
-	double outline = gog_renderer_line_size (
-		v->renderer, l->base.style->outline.width);
-
-	/* We only need internal padding if there is an outline */
-	if (outline > 0) {
-		double pad_x = gog_renderer_pt2r_x (v->renderer, l->swatch_padding_pts);
-		double pad_y = gog_renderer_pt2r_y (v->renderer, l->swatch_padding_pts);
-
-		res.x += outline + pad_x/2;
-		res.y += outline + pad_y/2;
-		res.w -= outline * 2. + pad_x;
-		res.h -= outline * 2. + pad_y;
-	}
-	(lview_parent_klass->size_allocate) (v, &res);
+	lview_parent_klass->size_request (v, avail);
 }
 
 typedef struct {
@@ -336,7 +321,7 @@ cb_render_elements (unsigned i, GogStyle const *base_style, char const *name,
 		style = (GogStyle *)base_style;
 		gog_renderer_push_style (v->renderer, style);
 		dat->line_path[0].y = dat->line_path[1].y =  swatch.y + swatch.h / 2.;
-		gog_renderer_draw_path (v->renderer, dat->line_path);
+		gog_renderer_draw_path (v->renderer, dat->line_path, NULL);
 		gog_renderer_draw_marker (v->renderer,
 			(dat->line_path[0].x + dat->line_path[1].x) / 2.,
 			dat->line_path[0].y);
@@ -346,7 +331,7 @@ cb_render_elements (unsigned i, GogStyle const *base_style, char const *name,
 		style->outline.color = RGBA_BLACK;
 
 		gog_renderer_push_style (v->renderer, style);
-		gog_renderer_draw_rectangle (v->renderer, &swatch);
+		gog_renderer_draw_rectangle (v->renderer, &swatch, NULL);
 	}
 	pos.x = swatch.x + dat->label_offset;
 	pos.y = swatch.y;
@@ -367,10 +352,6 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 	double pad_x = gog_renderer_pt2r_x (v->renderer, l->swatch_padding_pts);
 	double pad_y = gog_renderer_pt2r_y (v->renderer, l->swatch_padding_pts);
 
-	gog_renderer_push_style (v->renderer, l->base.style);
-	gog_renderer_draw_rectangle (v->renderer, &v->allocation);
-	gog_renderer_pop_style (v->renderer);
-
 	(lview_parent_klass->render) (v, bbox);
 
 	dat.view = v;
@@ -392,7 +373,7 @@ gog_legend_view_render (GogView *v, GogViewAllocation const *bbox)
 	dat.base_line = pad_y / 2.; /* bottom of the swatch */
 	dat.bottom    = v->residual.y + v->residual.h -
 		((GogLegendView *)v)->line_height;
-	gog_chart_foreach_elem (GOG_CHART (v->model->parent),
+	gog_chart_foreach_elem (GOG_CHART (v->model->parent), TRUE,
 		(GogEnumFunc) cb_render_elements, &dat);
 }
 
@@ -403,10 +384,9 @@ gog_legend_view_class_init (GogLegendViewClass *gview_klass)
 
 	lview_parent_klass = g_type_class_peek_parent (gview_klass);
 	view_klass->size_request    = gog_legend_view_size_request;
-	view_klass->size_allocate   = gog_legend_view_size_allocate;
 	view_klass->render	    = gog_legend_view_render;
 }
 
 static GSF_CLASS (GogLegendView, gog_legend_view,
 		  gog_legend_view_class_init, NULL,
-		  GOG_VIEW_TYPE)
+		  GOG_OUTLINED_VIEW_TYPE)
