@@ -45,9 +45,10 @@ GogPlot  *gog_plot_new_by_name	(char const *id);
 gboolean  gog_plot_make_similar	(GogPlot *dst, GogPlot const *src);
 
 void	  gog_plot_request_cardinality_update (GogPlot *plot);
-unsigned  gog_plot_get_cardinality (GogPlot *);
-void      gog_plot_foreach_elem    (GogPlot *,
-				    GogEnumFunc handler, gpointer data);
+void	  gog_plot_get_cardinality (GogPlot *plot,
+				    unsigned *full, unsigned *visible);
+void      gog_plot_foreach_elem    (GogPlot *plot, gboolean only_visible,
+  				    GogEnumFunc handler, gpointer data);
 GOData	 *gog_plot_get_axis_bounds (GogPlot *plot, GogAxisType axis,
 				    GogPlotBoundInfo *bounds);
 
