@@ -85,6 +85,32 @@ gog_renderer_gnome_print_finalize (GObject *obj)
 		(parent_klass->finalize) (obj);
 }
 
+/*
+ * print_make_rectangle_path
+ * @pc      print context
+ * @left    left side x coordinate
+ * @bottom  bottom side y coordinate
+ * @right   right side x coordinate
+ * @top     top side y coordinate
+ *
+ * Make a rectangular path.
+ * */
+
+static void
+print_make_rectangle_path (GnomePrintContext *pc,
+                           double left, double bottom,
+                           double right, double top)
+{
+        g_return_if_fail (pc != NULL);
+                                                                                
+        gnome_print_newpath   (pc);
+        gnome_print_moveto    (pc, left, bottom);
+        gnome_print_lineto    (pc, left, top);
+        gnome_print_lineto    (pc, right, top);
+        gnome_print_lineto    (pc, right, bottom);
+        gnome_print_closepath (pc);
+}
+
 static GnomeFont *
 get_font (GogRendererGnomePrint *prend, GOFont const *gf)
 {
@@ -101,7 +127,7 @@ get_font (GogRendererGnomePrint *prend, GOFont const *gf)
 			pango_font_description_get_family (desc),
 			pango_font_description_get_weight (desc) >= PANGO_WEIGHT_BOLD ? GNOME_FONT_BOLD : GNOME_FONT_REGULAR,
 			pango_font_description_get_style (desc) != PANGO_STYLE_NORMAL,
-			pango_font_description_get_size (desc) / PANGO_SCALE);
+			prend->base.zoom * pango_font_description_get_size (desc) / PANGO_SCALE);
 		g_ptr_array_index (prend->fonts, gf->font_index) = res;
 	}
 
@@ -119,6 +145,27 @@ set_color (GogRendererGnomePrint *prend, GOColor color)
 	gnome_print_setopacity (prend->gp_context, a);
 }
 
+static void
+gog_renderer_gnome_print_start_clipping (GogRenderer *rend)
+{
+	GogRendererGnomePrint *prend = GOG_RENDERER_GNOME_PRINT (rend);
+	
+	gnome_print_gsave (prend->gp_context);
+	print_make_rectangle_path (prend->gp_context, 
+				   rend->clip_rectangle.x, -rend->clip_rectangle.y,
+				   rend->clip_rectangle.w + rend->clip_rectangle.x, 
+				   -rend->clip_rectangle.h - rend->clip_rectangle.y);
+	gnome_print_clip (prend->gp_context);
+}
+
+static void
+gog_renderer_gnome_print_stop_clipping (GogRenderer *rend)
+{
+	GogRendererGnomePrint *prend = GOG_RENDERER_GNOME_PRINT (rend);
+
+	gnome_print_grestore (prend->gp_context);
+}
+
 static void
 draw_path (GogRendererGnomePrint *prend, ArtVpath const *path)
 {
@@ -139,7 +186,19 @@ draw_path (GogRendererGnomePrint *prend, ArtVpath const *path)
 }
 
 static void
-gog_renderer_gnome_print_draw_path (GogRenderer *renderer, ArtVpath const *path)
+setup_clip (GogRendererGnomePrint *prend, GogViewAllocation const *bound)
+{
+	gnome_print_gsave (prend->gp_context);
+	gnome_print_moveto (prend->gp_context, bound->x, -bound->y);
+	gnome_print_lineto (prend->gp_context, bound->x + bound->w, -bound->y);
+	gnome_print_lineto (prend->gp_context, bound->x + bound->w, -bound->y - bound->h);
+	gnome_print_lineto (prend->gp_context, bound->x, -bound->y - bound->h);
+	gnome_print_clip (prend->gp_context);
+}
+
+static void
+gog_renderer_gnome_print_draw_path (GogRenderer *renderer, ArtVpath const *path,
+				    GogViewAllocation const *bound)
 {
 	GogRendererGnomePrint *prend = GOG_RENDERER_GNOME_PRINT (renderer);
 	GogStyle const *style = renderer->cur_style;
@@ -147,8 +206,12 @@ gog_renderer_gnome_print_draw_path (GogRenderer *renderer, ArtVpath const *path)
 	set_color (prend, style->line.color);
 	gnome_print_setlinewidth (prend->gp_context, 
 		gog_renderer_line_size (renderer, style->line.width));
+	if (bound != NULL)
+		setup_clip (prend, bound);
 	draw_path (prend, path);
 	gnome_print_stroke (prend->gp_context);
+	if (bound != NULL)
+		gnome_print_grestore (prend->gp_context);
 }
 
 static void
@@ -166,7 +229,8 @@ print_image (GogRendererGnomePrint *prend, GdkPixbuf *image, int w, int h)
 
 #define PIXBUF_SIZE 1024
 static void
-gog_renderer_gnome_print_draw_polygon (GogRenderer *renderer, ArtVpath const *path, gboolean narrow)
+gog_renderer_gnome_print_draw_polygon (GogRenderer *renderer, ArtVpath const *path,
+				       gboolean narrow, GogViewAllocation const *bound)
 {
 	GogRendererGnomePrint *prend = GOG_RENDERER_GNOME_PRINT (renderer);
 	GogStyle const *style = renderer->cur_style;
@@ -179,6 +243,9 @@ gog_renderer_gnome_print_draw_polygon (GogRenderer *renderer, ArtVpath const *pa
 	ArtGradientLinear gradient;
 	ArtGradientStop stops[2];
 
+	if (bound != NULL)
+		setup_clip (prend, bound);
+
 	if (style->fill.type != GOG_FILL_STYLE_NONE || with_outline) {
 		draw_path (prend, path);
 		gnome_print_closepath (prend->gp_context);
@@ -316,6 +383,8 @@ gog_renderer_gnome_print_draw_polygon (GogRenderer *renderer, ArtVpath const *pa
 			gog_renderer_line_size (renderer, style->outline.width));
 		gnome_print_stroke (prend->gp_context);
 	}
+	if (bound != NULL)
+		gnome_print_grestore (prend->gp_context);
 }
 
 static void
@@ -385,7 +454,7 @@ static void
 gog_renderer_gnome_print_draw_marker (GogRenderer *renderer, double x, double y)
 {
 	GogRendererGnomePrint *prend = GOG_RENDERER_GNOME_PRINT (renderer);
-	GOMarker *marker = renderer->cur_style->marker;
+	GOMarker *marker = renderer->cur_style->marker.mark;
 	ArtVpath const *outline_path_raw, *fill_path_raw;
 	ArtVpath *outline_path, *fill_path;
 	double scaling[6], translation[6], affine[6];
@@ -435,12 +504,14 @@ gog_renderer_gnome_print_class_init (GogRendererClass *rend_klass)
 	GObjectClass *gobject_klass   = (GObjectClass *) rend_klass;
 
 	parent_klass = g_type_class_peek_parent (rend_klass);
-	gobject_klass->finalize	  = gog_renderer_gnome_print_finalize;
-	rend_klass->draw_path	  = gog_renderer_gnome_print_draw_path;
-	rend_klass->draw_polygon  = gog_renderer_gnome_print_draw_polygon;
-	rend_klass->draw_text	  = gog_renderer_gnome_print_draw_text;
-	rend_klass->draw_marker	  = gog_renderer_gnome_print_draw_marker;
-	rend_klass->measure_text  = gog_renderer_gnome_print_measure_text;
+	gobject_klass->finalize	  	= gog_renderer_gnome_print_finalize;
+	rend_klass->start_clipping  	= gog_renderer_gnome_print_start_clipping;
+	rend_klass->stop_clipping 	= gog_renderer_gnome_print_stop_clipping;
+	rend_klass->draw_path	  	= gog_renderer_gnome_print_draw_path;
+	rend_klass->draw_polygon  	= gog_renderer_gnome_print_draw_polygon;
+	rend_klass->draw_text	  	= gog_renderer_gnome_print_draw_text;
+	rend_klass->draw_marker	  	= gog_renderer_gnome_print_draw_marker;
+	rend_klass->measure_text  	= gog_renderer_gnome_print_measure_text;
 }
 
 static void
@@ -462,7 +533,9 @@ gog_graph_print_to_gnome_print (GogGraph *graph,
 	GogViewAllocation allocation;
 	GogRendererGnomePrint *prend =
 		g_object_new (GOG_RENDERER_GNOME_PRINT_TYPE,
-			      "model", graph, NULL);
+			      "model", graph,
+			      "zoom", 1.,
+			      NULL);
 	g_object_ref (gp_context);
 	prend->gp_context = gp_context;
 	allocation.x = 0.;
