@@ -47,6 +47,10 @@
 
 #include <libfoocanvas/foo-canvas-rect-ellipse.h>
 #include <glade/glade.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtkframe.h>
+#include <gtk/gtkvscrollbar.h>
+#include <gtk/gtkcheckmenuitem.h>
 #include <gsf/gsf-impl-utils.h>
 #include <string.h>
 
@@ -129,7 +133,7 @@ typedef struct {
 } AutoFormatGrid;
 typedef PreviewGridClass AutoFormatGridClass;
 
-static MStyle *
+static GnmStyle *
 afg_get_cell_style (PreviewGrid *pg, int col, int row)
 {
 	/* If this happens to be NULL the default style
@@ -138,7 +142,7 @@ afg_get_cell_style (PreviewGrid *pg, int col, int row)
 	return format_template_get_style (ag->ft, row, col);
 }
 
-static Value *
+static GnmValue *
 afg_get_cell_value (G_GNUC_UNUSED PreviewGrid *pg, int col, int row)
 {
 	char const *text;
@@ -220,7 +224,7 @@ templates_load (AutoFormatState *state)
 		return FALSE;
 
 	state->templates = category_group_get_templates_list (
-		state->current_category_group, COMMAND_CONTEXT (state->wbcg));
+		state->current_category_group, GNM_CMD_CONTEXT (state->wbcg));
 	for (l = state->templates; l != NULL; l = l->next) {
 		FormatTemplate *ft = l->data;
 		range_init (&ft->dimension,
@@ -549,7 +553,7 @@ dialog_autoformat (WorkbookControlGUI *wbcg)
 	AutoFormatState *state;
 	int i;
 
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
 		"autoformat.glade", NULL, NULL);
 	if (gui == NULL)
 		return;
