@@ -115,7 +115,7 @@ static gboolean
 cb_pref_notification_destroy (G_GNUC_UNUSED GtkWidget *page,
 			      guint notification)
 {
-	gconf_client_notify_remove (application_get_gconf_client (), notification);
+	gconf_client_notify_remove (gnm_app_get_gconf_client (), notification);
 	return TRUE;
 }
 
@@ -469,7 +469,7 @@ cb_value_edited (GtkCellRendererText *cell,
 	gnm_float  the_float;
 	gboolean    the_bool;
 	GnmValue       *value;
-	GConfClient *client = application_get_gconf_client ();
+	GConfClient *client = gnm_app_get_gconf_client ();
 	GConfSchema *the_schema;
 	gboolean     err;
 	GtkTreeModel *model = g_object_get_data (G_OBJECT (cell), "model");
@@ -660,7 +660,7 @@ cb_pref_font_set_fonts (GConfClient *gconf,
 
 static gboolean
 cb_pref_font_has_changed (G_GNUC_UNUSED FontSelector *fs,
-			  MStyle *mstyle, PrefState *state)
+			  GnmStyle *mstyle, PrefState *state)
 {
 	if (mstyle_is_element_set (mstyle, MSTYLE_FONT_SIZE))
 		gconf_client_set_float (state->gconf,
@@ -708,6 +708,99 @@ pref_font_initializer (PrefState *state,
 	return page;
 }
 
+/*******************************************************************************************/
+/*                     Default Header/Footer Font Selector                                 */
+/*******************************************************************************************/
+
+static void
+pref_font_hf_page_open (PrefState *state, G_GNUC_UNUSED gpointer data,
+		     G_GNUC_UNUSED GtkNotebook *notebook,
+		     G_GNUC_UNUSED gint page_num)
+{
+	dialog_pref_load_description_from_schema (state, "/schemas" PRINTSETUP_GCONF_HF_FONT_NAME);
+}
+
+static void
+cb_pref_font_hf_set_fonts (GConfClient *gconf,
+		        G_GNUC_UNUSED guint cnxn_id,
+			GConfEntry *entry,
+		        GtkWidget *page)
+{
+	if (entry == NULL || 0 == strcmp (gconf_entry_get_key (entry),
+					  PRINTSETUP_GCONF_HF_FONT_NAME)) {
+		char      *font_name = gconf_client_get_string (gconf,
+					  PRINTSETUP_GCONF_HF_FONT_NAME, NULL);
+		font_selector_set_name      (FONT_SELECTOR (page), font_name);
+		g_free (font_name);
+	}
+	if (entry == NULL || 0 == strcmp (gconf_entry_get_key (entry),
+					  PRINTSETUP_GCONF_HF_FONT_SIZE)) {
+		double    size = gconf_client_get_float (gconf,
+					  PRINTSETUP_GCONF_HF_FONT_SIZE, NULL);
+		font_selector_set_points    (FONT_SELECTOR (page), size);
+	}
+	if (entry == NULL || 0 == strcmp (gconf_entry_get_key (entry),
+					  PRINTSETUP_GCONF_HF_FONT_BOLD)
+	    || 0 == strcmp (gconf_entry_get_key (entry),
+			    PRINTSETUP_GCONF_HF_FONT_ITALIC)) {
+		gboolean  is_bold = gconf_client_get_bool (gconf,
+			    PRINTSETUP_GCONF_HF_FONT_BOLD, NULL);
+		gboolean  is_italic = gconf_client_get_bool (gconf,
+			    PRINTSETUP_GCONF_HF_FONT_ITALIC, NULL);
+		font_selector_set_style     (FONT_SELECTOR (page), is_bold, is_italic);
+	}
+}
+
+static gboolean
+cb_pref_font_hf_has_changed (G_GNUC_UNUSED FontSelector *fs,
+			  GnmStyle *mstyle, PrefState *state)
+{
+	if (mstyle_is_element_set (mstyle, MSTYLE_FONT_SIZE))
+		gconf_client_set_float (state->gconf,
+					PRINTSETUP_GCONF_HF_FONT_SIZE,
+					mstyle_get_font_size (mstyle), NULL);
+	if (mstyle_is_element_set (mstyle, MSTYLE_FONT_NAME))
+		gconf_client_set_string (state->gconf,
+					 PRINTSETUP_GCONF_HF_FONT_NAME,
+					 mstyle_get_font_name (mstyle), NULL);
+	if (mstyle_is_element_set (mstyle, MSTYLE_FONT_BOLD))
+		gconf_client_set_bool (state->gconf,
+				       PRINTSETUP_GCONF_HF_FONT_BOLD,
+				       mstyle_get_font_bold (mstyle), NULL);
+	if (mstyle_is_element_set (mstyle, MSTYLE_FONT_ITALIC))
+		gconf_client_set_bool (state->gconf,
+				       PRINTSETUP_GCONF_HF_FONT_ITALIC,
+				       mstyle_get_font_italic (mstyle), NULL);
+	return TRUE;
+}
+
+static GtkWidget *
+pref_font_hf_initializer (PrefState *state,
+		       G_GNUC_UNUSED gpointer data,
+		       G_GNUC_UNUSED GtkNotebook *notebook,
+		       G_GNUC_UNUSED gint page_num)
+{
+	GtkWidget *page = font_selector_new ();
+	guint notification;
+
+	cb_pref_font_hf_set_fonts (state->gconf, 0, NULL, page);
+
+	notification = gconf_client_notify_add (state->gconf, PRINTSETUP_GCONF_DIRECTORY,
+						(GConfClientNotifyFunc) cb_pref_font_hf_set_fonts,
+						page, NULL, NULL);
+
+	g_signal_connect (G_OBJECT (page),
+		"destroy",
+		G_CALLBACK (cb_pref_notification_destroy), GINT_TO_POINTER (notification));
+	g_signal_connect (G_OBJECT (page),
+		"font_changed",
+		G_CALLBACK (cb_pref_font_hf_has_changed), state);
+
+	gtk_widget_show_all (page);
+
+	return page;
+}
+
 /*******************************************************************************************/
 /*                     Undo Preferences Page                                              */
 /*******************************************************************************************/
@@ -913,10 +1006,10 @@ cb_pref_sort_set_case (GConfClient *gconf,
 static void
 cb_pref_sort_case_toggled(GtkToggleButton *button, PrefState *state)
 {
-		gconf_client_set_bool (state->gconf,
-				       GNUMERIC_GCONF_SORT_DEFAULT_BY_CASE,
-				       gtk_toggle_button_get_active (button),
-				       NULL);
+	gconf_client_set_bool (state->gconf,
+			       GNUMERIC_GCONF_SORT_DEFAULT_BY_CASE,
+			       gtk_toggle_button_get_active (button),
+			       NULL);
 }
 
 static void
@@ -936,10 +1029,10 @@ cb_pref_sort_set_ascending (GConfClient *gconf,
 static void
 cb_pref_sort_ascending_toggled(GtkToggleButton *button, PrefState *state)
 {
-		gconf_client_set_bool (state->gconf,
-				       GNUMERIC_GCONF_SORT_DEFAULT_ASCENDING,
-				       gtk_toggle_button_get_active (button),
-				       NULL);
+	gconf_client_set_bool (state->gconf,
+			       GNUMERIC_GCONF_SORT_DEFAULT_ASCENDING,
+			       gtk_toggle_button_get_active (button),
+			       NULL);
 }
 
 static void
@@ -1126,7 +1219,7 @@ cb_pref_window_transition_keys_toggled (GtkToggleButton *button, PrefState *stat
 			       GNUMERIC_GCONF_GUI_ED_TRANSITION_KEYS,
 			       gtk_toggle_button_get_active (button),
 			       NULL);
-	application_set_transition_keys(gtk_toggle_button_get_active (button));
+	gnm_app_set_transition_keys(gtk_toggle_button_get_active (button));
 }
 
 
@@ -1162,7 +1255,6 @@ cb_pref_window_live_scrolling_toggled (GtkToggleButton *button, PrefState *state
 			       NULL);
 }
 
-
 static GtkWidget *
 pref_window_page_initializer (PrefState *state,
 			      G_GNUC_UNUSED gpointer data,
@@ -1300,10 +1392,10 @@ cb_pref_file_set_overwrite (GConfClient *gconf,
 static void
 cb_pref_file_overwrite_toggled (GtkToggleButton *button, PrefState *state)
 {
-		gconf_client_set_bool (state->gconf,
-				       GNUMERIC_GCONF_FILE_OVERWRITE_DEFAULT,
-				       gtk_toggle_button_get_active (button),
-				       NULL);
+	gconf_client_set_bool (state->gconf,
+			       GNUMERIC_GCONF_FILE_OVERWRITE_DEFAULT,
+			       gtk_toggle_button_get_active (button),
+			       NULL);
 }
 
 static void
@@ -1323,10 +1415,10 @@ cb_pref_file_set_single_sheet_warn (GConfClient *gconf,
 static void
 cb_pref_file_single_sheet_warn_toggled (GtkToggleButton *button, PrefState *state)
 {
-		gconf_client_set_bool (state->gconf,
-				       GNUMERIC_GCONF_FILE_SINGLE_SHEET_SAVE,
-				       gtk_toggle_button_get_active (button),
-				       NULL);
+	gconf_client_set_bool (state->gconf,
+			       GNUMERIC_GCONF_FILE_SINGLE_SHEET_SAVE,
+			       gtk_toggle_button_get_active (button),
+			       NULL);
 }
 
 static void
@@ -1412,6 +1504,7 @@ static page_info_t page_info[] = {
 	{N_("Sorting"),    GTK_STOCK_SORT_ASCENDING,     NULL, pref_sort_page_initializer, pref_sort_page_open, NULL},
 	{N_("Various"),    GTK_STOCK_PREFERENCES,        NULL, pref_tree_initializer, pref_tree_page_open, pref_tree_data},
 	{N_("Internal"),   GTK_STOCK_DIALOG_ERROR,       "5",  pref_tree_initializer, pref_tree_page_open, pref_tree_data_danger},
+	{N_("Header/Footer"), GTK_STOCK_ITALIC,	         "0",  pref_font_hf_initializer, pref_font_hf_page_open, NULL},
 	{NULL, NULL, NULL, NULL, NULL, NULL},
 };
 
@@ -1467,7 +1560,7 @@ cb_preferences_destroy (G_GNUC_UNUSED GtkWidget *widget,
 
 	g_free (state);
 
-	application_set_pref_dialog (NULL);
+	gnm_app_set_pref_dialog (NULL);
 
 	return FALSE;
 }
@@ -1504,14 +1597,14 @@ dialog_preferences (WorkbookControlGUI *wbcg, gint page)
 	GtkTreeViewColumn *column;
 	GtkTreeSelection  *selection;
 
-	w = application_get_pref_dialog ();
+	w = gnm_app_get_pref_dialog ();
 	if (w) {
 		gtk_widget_show (w);
 		gdk_window_raise (w->window);
 		return;
 	}
 
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
 		"preferences.glade", NULL, NULL);
 	if (gui == NULL)
 		return;
@@ -1521,7 +1614,7 @@ dialog_preferences (WorkbookControlGUI *wbcg, gint page)
 	state->dialog     = glade_xml_get_widget (gui, "preferences");
 	state->notebook   = glade_xml_get_widget (gui, "notebook");
 	state->pages      = NULL;
-	state->gconf      = application_get_gconf_client ();
+	state->gconf      = gnm_app_get_gconf_client ();
 	state->description = GTK_TEXT_VIEW (glade_xml_get_widget (gui, "description"));
 	state->wb	  = wb_control_workbook (WORKBOOK_CONTROL (wbcg));
 
@@ -1565,7 +1658,7 @@ dialog_preferences (WorkbookControlGUI *wbcg, gint page)
 		"destroy",
 		G_CALLBACK (cb_preferences_destroy), state);
 
-	application_set_pref_dialog (state->dialog);
+	gnm_app_set_pref_dialog (state->dialog);
 
 	for (i = 0; page_info[i].page_initializer; i++) {
 		page_info_t *this_page =  &page_info[i];
