@@ -48,6 +48,12 @@
 #include <libfoocanvas/foo-canvas-text.h>
 #include <libfoocanvas/foo-canvas-rect-ellipse.h>
 #include <glade/glade.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtktable.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtkmenuitem.h>
 #include <stdio.h>
 
 /* FIXME: do not hardcode pixel counts.  */
@@ -991,7 +997,7 @@ do_hf_customize (gboolean header, PrinterSetupState *state)
 		return;
 	}
 
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (state->wbcg),
+	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (state->wbcg),
 		"hf-config.glade", NULL, NULL);
         if (gui == NULL)
                 return;
@@ -1264,7 +1270,6 @@ do_setup_page_info (PrinterSetupState *state)
 	GtkWidget *order_rd  = glade_xml_get_widget (state->gui, "radio-order-right");
 	GtkWidget *order_dr  = glade_xml_get_widget (state->gui, "radio-order-down");
 	GtkWidget *order_table = glade_xml_get_widget (state->gui, "page-order-table");
-	GtkCombo *comments_combo;
 	GtkWidget *order;
 
 	state->area_entry = gnm_expr_entry_new (state->wbcg, TRUE);
@@ -1336,9 +1341,8 @@ do_setup_page_info (PrinterSetupState *state)
 				  GTK_WIDGET (gnm_expr_entry_get_entry (state->top_entry)));
 	gnumeric_editable_enters (GTK_WINDOW (state->dialog),
 				  GTK_WIDGET (gnm_expr_entry_get_entry (state->left_entry)));
-	comments_combo = GTK_COMBO (glade_xml_get_widget (state->gui,
-							  "comments-combo"));
-	gnumeric_combo_enters (GTK_WINDOW (state->dialog), comments_combo);
+	gnumeric_combo_enters (GTK_WINDOW (state->dialog),
+		glade_xml_get_widget (state->gui, "comments-combo"));
 
 	if (state->pi->repeat_top.use)
 		gnm_expr_entry_load_from_range (
@@ -1381,7 +1385,6 @@ do_setup_page (PrinterSetupState *state)
 	PrintInformation *pi = state->pi;
 	GtkWidget *scale_percent_spin, *scale_width_spin, *scale_height_spin;
 	GtkWidget *paper_selector;
-	GtkCombo *first_page_combo;
 	GtkTable *table;
 	GladeXML *gui;
 	const char *toggle;
@@ -1433,9 +1436,8 @@ do_setup_page (PrinterSetupState *state)
 		GTK_SPIN_BUTTON (scale_height_spin), pi->scaling.dim.rows);
 	gnumeric_editable_enters (GTK_WINDOW (state->dialog),
 				      GTK_WIDGET (scale_height_spin));
-	first_page_combo =
-		GTK_COMBO (glade_xml_get_widget (gui, "first-page-combo"));
-	gnumeric_combo_enters (GTK_WINDOW (state->dialog), first_page_combo);
+	gnumeric_combo_enters (GTK_WINDOW (state->dialog),
+		glade_xml_get_widget (gui, "first-page-combo"));
 }
 
 static Sheet *
@@ -1496,9 +1498,12 @@ cb_do_print_ok (G_GNUC_UNUSED GtkWidget *w,
 static void
 cb_do_print (G_GNUC_UNUSED GtkWidget *w, PrinterSetupState *state)
 {
+	WorkbookControlGUI *wbcg = state->wbcg;
+	Sheet *sheet = state->sheet;
+
 	cb_do_print_ok (NULL, state);
 
-	sheet_print (state->wbcg, state->sheet, 
+	sheet_print (wbcg, sheet, 
 		     FALSE, PRINT_ACTIVE_SHEET);
 }
 
@@ -1620,7 +1625,7 @@ printer_setup_state_new (WorkbookControlGUI *wbcg, Sheet *sheet)
 	PrinterSetupState *state;
 	GladeXML *gui;
 
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
 		"print.glade", NULL, NULL);
         if (gui == NULL)
                 return NULL;
