@@ -110,7 +110,8 @@ stf_export_dialog_format_page_init (GladeXML *gui)
 		   FALSE);
 	}
 	
-	     
+	data->format_preserve = GTK_CHECK_BUTTON 
+		(glade_xml_get_widget (gui, "format_preserve"));	
 
 	table = glade_xml_get_widget (gui, "format_table");
 	gtk_table_attach_defaults (GTK_TABLE (table), GTK_WIDGET (data->format_charset),
@@ -179,6 +180,11 @@ stf_export_dialog_format_page_result (StfE_FormatPageData_t *data, StfExportOpti
 	}
 
 	stf_export_options_set_transliterate_mode (export_options, transliteratemode);
+	
+	stf_export_options_set_format_mode 
+		(export_options, 
+		 gtk_toggle_button_get_active 
+		 (GTK_TOGGLE_BUTTON (data->format_preserve)));
 
 	text = gtk_editable_get_chars (GTK_EDITABLE (data->format_quotechar->entry), 0, -1);
 	stf_export_options_set_quoting_char (export_options, g_utf8_get_char (text));
