@@ -26,6 +26,7 @@
 #include <gsf/gsf-output.h>
 #include <gsf/gsf-output-stdio.h>
 #include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf-utils.h>
 #include <string.h>
 
 static void
@@ -51,6 +52,12 @@ gnm_file_opener_finalize (GObject *obj)
 	G_OBJECT_CLASS (g_type_class_peek (G_TYPE_OBJECT))->finalize (obj);
 }
 
+static gboolean
+gnm_file_opener_can_probe_real (GnmFileOpener const *fo, FileProbeLevel pl)
+{
+	return fo->probe_func != NULL;
+}
+
 static gboolean
 gnm_file_opener_probe_real (GnmFileOpener const *fo, GsfInput *input,
                              FileProbeLevel pl)
@@ -84,6 +91,7 @@ gnm_file_opener_class_init (GnmFileOpenerClass *klass)
 {
 	G_OBJECT_CLASS (klass)->finalize = gnm_file_opener_finalize;
 
+	klass->can_probe = gnm_file_opener_can_probe_real;
 	klass->probe = gnm_file_opener_probe_real;
 	klass->open = gnm_file_opener_open_real;
 }
@@ -202,6 +210,13 @@ gnm_file_opener_is_encoding_dependent (GnmFileOpener const *fo)
 	return fo->encoding_dependent;
 }
 
+gboolean
+gnm_file_opener_can_probe (GnmFileOpener const *fo, FileProbeLevel pl)
+{
+	g_return_val_if_fail (IS_GNM_FILE_OPENER (fo), FALSE);
+
+	return GNM_FILE_OPENER_METHOD (fo, can_probe) (fo, pl);
+}
 
 
 
@@ -783,6 +798,27 @@ gnm_file_saver_for_mime_type (gchar const *mime_type)
 	return (NULL);
 }
 
+/**
+ * gnm_file_saver_for_file_name :
+ * @file_name :
+ *
+ * Searches for file opener with given @filename, registered using
+ * gnm_file_opener_register
+ *
+ * Return value: GnmFileOpener object or NULL if opener cannot be found.
+ **/
+GnmFileSaver *
+gnm_file_saver_for_file_name (char const *file_name)
+{
+	GList *l;
+	char const *extension = gsf_extension_pointer (file_name);
+
+	for (l = file_saver_list; l != NULL; l = l->next)
+		if (!strcmp (gnm_file_saver_get_extension (l->data), extension))
+			return l->data;
+	return NULL;
+}
+
 /**
  * gnm_file_opener_for_id:
  * @id          : File opener's ID
