@@ -99,7 +99,7 @@ gnm_check_ctrl_mask (GnmCanvas *gcanvas,guint keyval)
 	}
 
 	if (fmt != NULL) {
-		MStyle *mstyle = mstyle_new ();
+		GnmStyle *mstyle = mstyle_new ();
 
 		mstyle_set_format_text (mstyle, fmt);
 		cmd_selection_format (WORKBOOK_CONTROL (wbcg), mstyle, NULL, desc);
@@ -119,12 +119,13 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 	Sheet *sheet = sc->sheet;
 	SheetView *sv = sc->view;
 	WorkbookControlGUI *wbcg = gcanvas->simple.scg->wbcg;
+	gboolean delayed_movement = FALSE;
 	gboolean jump_to_bounds = event->state & GDK_CONTROL_MASK;
 	int state = gnumeric_filter_modifiers (event->state);
 	void (*movefn) (SheetControlGUI *, int n,
 			gboolean jump, gboolean horiz);
 
-	gboolean transition_keys = application_use_transition_keys();
+	gboolean transition_keys = gnm_app_use_transition_keys();
 	gboolean end_mode = wbcg->last_key_was_end;
 	
 	/* Magic : Some of these are accelerators,
@@ -160,12 +161,12 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 	case GDK_Left:
 		if (event->state & SCROLL_LOCK_MASK)
 			scg_set_left_col (gcanvas->simple.scg, gcanvas->first.col - 1);
-		else if (transition_keys && jump_to_bounds)
-			scg_queue_movement 
-				(gcanvas->simple.scg, movefn,
+		else if (transition_keys && jump_to_bounds) {
+			delayed_movement = TRUE;
+			scg_queue_movement (gcanvas->simple.scg, movefn,
 				 -(gcanvas->last_visible.col-gcanvas->first.col),
 				 FALSE, TRUE);
-		else
+		} else
 			(*movefn) (gcanvas->simple.scg, -1, jump_to_bounds || end_mode, TRUE);
 		break;
 
@@ -173,12 +174,12 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 	case GDK_Right:
 		if (event->state & SCROLL_LOCK_MASK)
 			scg_set_left_col (gcanvas->simple.scg, gcanvas->first.col + 1);
-		else if (transition_keys && jump_to_bounds)
-			scg_queue_movement 
-				(gcanvas->simple.scg, movefn,
+		else if (transition_keys && jump_to_bounds) {
+			delayed_movement = TRUE;
+			scg_queue_movement (gcanvas->simple.scg, movefn,
 				 gcanvas->last_visible.col-gcanvas->first.col,
 				 FALSE, TRUE);
-		else
+		} else
 			(*movefn) (gcanvas->simple.scg, 1, jump_to_bounds || end_mode, TRUE);
 		break;
 
@@ -186,12 +187,12 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 	case GDK_Up:
 		if (event->state & SCROLL_LOCK_MASK)
 			scg_set_top_row (gcanvas->simple.scg, gcanvas->first.row - 1);
-		else if (transition_keys && jump_to_bounds)
-			scg_queue_movement 
-				(gcanvas->simple.scg, movefn,
+		else if (transition_keys && jump_to_bounds) {
+			delayed_movement = TRUE;
+			scg_queue_movement (gcanvas->simple.scg, movefn,
 				 -(gcanvas->last_visible.row-gcanvas->first.row),
 				 FALSE, FALSE);
-		else
+		} else
 			(*movefn) (gcanvas->simple.scg, -1, jump_to_bounds || end_mode, FALSE);
 		break;
 
@@ -199,13 +200,12 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 	case GDK_Down:
 		if (event->state & SCROLL_LOCK_MASK)
 			scg_set_top_row (gcanvas->simple.scg, gcanvas->first.row + 1);
-		else if (transition_keys && jump_to_bounds)
-			scg_queue_movement 
-				(gcanvas->simple.scg, movefn,
+		else if (transition_keys && jump_to_bounds) {
+			delayed_movement = TRUE;
+			scg_queue_movement (gcanvas->simple.scg, movefn,
 				 gcanvas->last_visible.row-gcanvas->first.row,
 				 FALSE, FALSE);
-			
-		else
+		} else
 			(*movefn) (gcanvas->simple.scg, 1, jump_to_bounds || end_mode, FALSE);
 		break;
 
@@ -213,28 +213,34 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 	case GDK_Page_Up:
 		if ((event->state & GDK_CONTROL_MASK) != 0)
 			gtk_notebook_prev_page (wbcg->notebook);
-		else if ((event->state & GDK_MOD1_MASK) == 0)
+		else if ((event->state & GDK_MOD1_MASK) == 0) {
+			delayed_movement = TRUE;
 			scg_queue_movement (gcanvas->simple.scg, movefn,
 				-(gcanvas->last_visible.row-gcanvas->first.row),
 				FALSE, FALSE);
-		else
+		} else {
+			delayed_movement = TRUE;
 			scg_queue_movement (gcanvas->simple.scg, movefn,
 				-(gcanvas->last_visible.col-gcanvas->first.col),
 				FALSE, TRUE);
+		}
 		break;
 
 	case GDK_KP_Page_Down:
 	case GDK_Page_Down:
 		if ((event->state & GDK_CONTROL_MASK) != 0)
 			gtk_notebook_next_page (wbcg->notebook);
-		else if ((event->state & GDK_MOD1_MASK) == 0)
+		else if ((event->state & GDK_MOD1_MASK) == 0) {
+			delayed_movement = TRUE;
 			scg_queue_movement (gcanvas->simple.scg, movefn,
 				gcanvas->last_visible.row-gcanvas->first.row,
 				FALSE, FALSE);
-		else
+		} else {
+			delayed_movement = TRUE;
 			scg_queue_movement (gcanvas->simple.scg, movefn,
 				gcanvas->last_visible.col-gcanvas->first.col,
 				FALSE, TRUE);
+		}
 		break;
 
 	case GDK_KP_Home:
@@ -333,7 +339,7 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 
 	case GDK_Escape:
 		wbcg_edit_finish (wbcg, FALSE, NULL);
-		application_clipboard_unant ();
+		gnm_app_clipboard_unant ();
 		break;
 
 	case GDK_F4:
@@ -382,10 +388,12 @@ gnm_canvas_key_mode_sheet (GnmCanvas *gcanvas, GdkEventKey *event)
 		wbcg_set_end_mode(wbcg, FALSE);
 	}
 
-	if (wbcg_is_editing (wbcg))
-		sheet_update_only_grid (sheet);
-	else
-		sheet_update (sheet);
+	if (!delayed_movement) {
+		if (wbcg_is_editing (wbcg))
+			sheet_update_only_grid (sheet);
+		else
+			sheet_update (sheet);
+	}
 
 	return TRUE;
 }
@@ -400,7 +408,7 @@ gnm_canvas_key_mode_object (GnmCanvas *gcanvas, GdkEventKey *event)
 	switch (event->keyval) {
 	case GDK_Escape:
 		scg_mode_edit (sc);
-		application_clipboard_unant ();
+		gnm_app_clipboard_unant ();
 		return TRUE;;
 
 	case GDK_BackSpace: /* Ick! */
