@@ -19,7 +19,7 @@
 
 #include "item-cursor.h"
 #include "gnumeric-canvas.h"
-#include "sheet-control-gui.h"
+#include "sheet-control-gui-priv.h"
 #include "sheet.h"
 #include "sheet-view.h"
 #include "sheet-style.h"
@@ -63,7 +63,7 @@ struct _ItemEdit {
 
 	/* When editing, if the cursor is inside a cell name, or a cell range,
 	 * we highlight this on the spreadsheet. */
-	FooCanvasItem *feedback_cursor;
+	FooCanvasItem *feedback_cursor [SCG_NUM_PANES];
 	gboolean       feedback_disabled;
 };
 
@@ -78,10 +78,13 @@ enum {
 static void
 ie_destroy_feedback_range (ItemEdit *ie)
 {
-	if (ie->feedback_cursor != NULL) {
-		gtk_object_destroy (GTK_OBJECT (ie->feedback_cursor));
-		ie->feedback_cursor = NULL;
-	}
+	int i = G_N_ELEMENTS (ie->feedback_cursor);
+
+	while (i-- > 0)
+		if (ie->feedback_cursor[i] != NULL) {
+			gtk_object_destroy (GTK_OBJECT (ie->feedback_cursor[i]));
+			ie->feedback_cursor[i] = NULL;
+		}
 }
 
 /* WARNING : DO NOT CALL THIS FROM FROM UPDATE.  It may create another
@@ -100,16 +103,18 @@ ie_scan_for_range (ItemEdit *ie)
 	if (!ie->feedback_disabled) {
 		gnm_expr_expr_find_range (gee);
 		if (gnm_expr_entry_get_rangesel (gee, &range, &parse_sheet) &&
-		    (parse_sheet == sheet)) {
-			if (ie->feedback_cursor == NULL)
-				ie->feedback_cursor = foo_canvas_item_new (
-					FOO_CANVAS_GROUP (ie->canvas_item.canvas->root),
-					item_cursor_get_type (),
-					"SheetControlGUI",	ie->scg,
-					"style",		ITEM_CURSOR_BLOCK,
-					"color",		"blue",
-					NULL);
-			item_cursor_bound_set (ITEM_CURSOR (ie->feedback_cursor), &range);
+		    parse_sheet == sheet) {
+			SCG_FOREACH_PANE (ie->scg, pane, {
+				if (ie->feedback_cursor[i] == NULL)
+					ie->feedback_cursor[i] = foo_canvas_item_new (
+						FOO_CANVAS_GROUP (FOO_CANVAS (pane->gcanvas)->root),
+						item_cursor_get_type (),
+						"SheetControlGUI",	ie->scg,
+						"style",		ITEM_CURSOR_BLOCK,
+						"color",		"blue",
+						NULL);
+				item_cursor_bound_set (ITEM_CURSOR (ie->feedback_cursor[i]), &range);
+			});
 			return;
 		}
 	}
@@ -194,11 +199,45 @@ item_edit_point (FooCanvasItem *item, double c_x, double c_y, int cx, int cy,
 static int
 item_edit_event (FooCanvasItem *item, GdkEvent *event)
 {
-	/* FIXME : Handle mouse events here */
 	switch (event->type){
 	case GDK_ENTER_NOTIFY:
 		gnm_widget_set_cursor_type (GTK_WIDGET (item->canvas), GDK_XTERM);
 		return TRUE;
+
+	case GDK_BUTTON_PRESS:
+		if (event->button.button == 1) {
+			ItemEdit *ie = ITEM_EDIT (item);
+			GtkEditable *ed = GTK_EDITABLE (ie->entry);
+			double x = event->button.x, y = event->button.y;
+			int target_index, trailing;
+
+			x -= MIN (item->x1, item->x2);
+			y -= MIN (item->y1, item->y2);
+
+			if (pango_layout_xy_to_index (ie->layout,
+						      x * PANGO_SCALE, y * PANGO_SCALE,
+						      &target_index, &trailing)) {
+				int preedit = GNM_CANVAS (item->canvas)->preedit_length;
+				char const *text = pango_layout_get_text (ie->layout);
+				gint cur_index = gtk_editable_get_position (ed);
+				cur_index = g_utf8_offset_to_pointer (text, cur_index) - text;
+
+				if (target_index >= cur_index && preedit > 0) {
+					if (target_index < (cur_index + preedit)) {
+						target_index = cur_index;
+						trailing = 0;
+					} else
+						target_index -= preedit;
+				}
+				gtk_editable_set_position (GTK_EDITABLE (ie->entry),
+					g_utf8_pointer_to_offset (text, text + target_index)
+					+ trailing);
+
+				return TRUE;
+			}
+		}
+		break;
+
 	default :
 		break;
 	}
@@ -395,7 +434,7 @@ cb_item_edit_cursor_blink (ItemEdit *ie)
 
 	ie->cursor_visible = !ie->cursor_visible;
 
-	foo_canvas_item_request_update (item);
+	foo_canvas_item_request_redraw (item);
 	return TRUE;
 }
 
@@ -431,6 +470,7 @@ static void
 item_edit_init (ItemEdit *ie)
 {
 	FooCanvasItem *item = FOO_CANVAS_ITEM (ie);
+	int i;
 
 	item->x1 = 0;
 	item->y1 = 0;
@@ -444,8 +484,9 @@ item_edit_init (ItemEdit *ie)
 	ie->style      = NULL;
 	ie->cursor_visible = TRUE;
 	ie->feedback_disabled = FALSE;
-	ie->feedback_cursor = NULL;
 	ie->fill_gc = NULL;
+	for (i = G_N_ELEMENTS (ie->feedback_cursor); i-- > 0 ; )
+		ie->feedback_cursor[i] = NULL;
 }
 
 /*
@@ -499,6 +540,10 @@ entry_event (GtkEntry *entry, GdkEvent *event, FooCanvasItem *item)
 static int
 entry_cursor_event (GtkEntry *entry, GParamSpec *pspec, FooCanvasItem *item)
 {
+	/* ensure we draw a cursor when moving quickly no matter what the
+	 * current state is */
+	ITEM_EDIT (item)->cursor_visible = TRUE;
+
 	entry_changed (NULL, item);
 	return TRUE;
 }
