@@ -238,7 +238,7 @@ gnm_component_factory (BonoboGenericFactory *this,
 		static gboolean p_initialized = FALSE;
 
 		if (!p_initialized) {
-			plugins_init (COMMAND_CONTEXT (wbc));
+			plugins_init (GNM_CMD_CONTEXT (wbc));
 			p_initialized = TRUE;
 		}
 	}
@@ -252,7 +252,7 @@ main (int argc, char *argv [])
 
 	BONOBO_FACTORY_INIT ("gnumeric-component", VERSION, &argc, argv);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	gnm_common_init ();
+	gnm_common_init (TRUE);
 
 	return bonobo_generic_factory_main ("OAFIID:GNOME_Gnumeric_Factory",
 					    gnm_component_factory, NULL);
