@@ -793,8 +793,8 @@ static const unsigned short yyrline[] =
      525,   526,   527,   528,   529,   530,   531,   532,   533,   534,
      535,   536,   537,   538,   539,   544,   548,   549,   550,   552,
      572,   578,   579,   597,   618,   650,   651,   654,   677,   686,
-     698,   699,   700,   704,   710,   715,   721,   731,   734,   735,
-     736,   739,   750,   763,   776,   779,   784
+     698,   699,   700,   704,   710,   715,   726,   736,   739,   740,
+     741,   744,   755,   768,   781,   784,   789
 };
 #endif
 
@@ -1926,15 +1926,20 @@ yyreduce:
   case 45:
 #line 715 "parser.y"
     {
+		GSList *tmp = yyvsp[0].list;
 		unregister_allocation (yyvsp[0].list);
 		unregister_allocation (yyvsp[-2].expr);
-		yyval.list = g_slist_prepend (yyvsp[0].list, yyvsp[-2].expr);
+
+		if (tmp == NULL)
+			tmp = gnm_expr_list_prepend (NULL, gnm_expr_new_constant (value_new_empty ()));
+
+		yyval.list = g_slist_prepend (tmp, yyvsp[-2].expr);
 		register_expr_list_allocation (yyval.list);
 	}
     break;
 
   case 46:
-#line 721 "parser.y"
+#line 726 "parser.y"
     {
 		GSList *tmp = yyvsp[0].list;
 		unregister_allocation (yyvsp[0].list);
@@ -1948,27 +1953,27 @@ yyreduce:
     break;
 
   case 47:
-#line 731 "parser.y"
+#line 736 "parser.y"
     { yyval.list = NULL; }
     break;
 
   case 48:
-#line 734 "parser.y"
+#line 739 "parser.y"
     { yyval.expr = yyvsp[0].expr; }
     break;
 
   case 49:
-#line 735 "parser.y"
+#line 740 "parser.y"
     { yyval.expr = fold_negative (yyvsp[0].expr); }
     break;
 
   case 50:
-#line 736 "parser.y"
+#line 741 "parser.y"
     { yyval.expr = parse_string_as_value (yyvsp[0].expr); }
     break;
 
   case 51:
-#line 739 "parser.y"
+#line 744 "parser.y"
     {
 		unregister_allocation (yyvsp[0].expr);
 		yyval.list = g_slist_prepend (NULL, yyvsp[0].expr);
@@ -1977,7 +1982,7 @@ yyreduce:
     break;
 
   case 52:
-#line 750 "parser.y"
+#line 755 "parser.y"
     {
 		if (state->array_col_separator == ',') {
 			unregister_allocation (yyvsp[0].list);
@@ -1994,7 +1999,7 @@ yyreduce:
     break;
 
   case 53:
-#line 763 "parser.y"
+#line 768 "parser.y"
     {
 		if (state->array_col_separator == '\\') {
 			unregister_allocation (yyvsp[0].list);
@@ -2011,12 +2016,12 @@ yyreduce:
     break;
 
   case 54:
-#line 776 "parser.y"
+#line 781 "parser.y"
     { yyval.list = NULL; }
     break;
 
   case 55:
-#line 779 "parser.y"
+#line 784 "parser.y"
     {
 		unregister_allocation (yyvsp[0].list);
 		yyval.list = g_slist_prepend (NULL, yyvsp[0].list);
@@ -2025,7 +2030,7 @@ yyreduce:
     break;
 
   case 56:
-#line 784 "parser.y"
+#line 789 "parser.y"
     {
 		unregister_allocation (yyvsp[0].list);
 		unregister_allocation (yyvsp[-2].list);
@@ -2038,7 +2043,7 @@ yyreduce:
     }
 
 /* Line 999 of yacc.c.  */
-#line 2042 "y.tab.c"
+#line 2047 "y.tab.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -2232,7 +2237,7 @@ yyreturn:
 }
 
 
-#line 791 "parser.y"
+#line 796 "parser.y"
 
 
 static char const *
