@@ -457,12 +457,12 @@ scg_colrow_size_set (SheetControlGUI *scg,
 	/* If all cols/rows in the selection are completely selected
 	 * then resize all of them, otherwise just resize the selected col/row.
 	 */
-	if (!sv_is_full_colrow_selected (sv, is_cols, index)) {
-		ColRowIndexList *s = colrow_get_index_list (index, index, NULL);
-		cmd_resize_colrow (wbc, sv->sheet, is_cols, s, new_size_pixels);
-	} else
-		workbook_cmd_resize_selected_colrow (wbc, is_cols,
-			sv->sheet, new_size_pixels);
+	if (!sv_is_full_colrow_selected (sv, is_cols, index))
+		cmd_resize_colrow (wbc, sv->sheet, is_cols,
+			colrow_get_index_list (index, index, NULL), new_size_pixels);
+	else
+		workbook_cmd_resize_selected_colrow (wbc, sv->sheet, is_cols,
+			new_size_pixels);
 }
 
 void
@@ -1089,6 +1089,13 @@ scg_set_panes (SheetControl *sc)
 	}
 }
 
+static void
+cb_wbc_destroyed (SheetControlGUI *scg)
+{
+	scg->wbcg = NULL;
+	scg->sheet_control.wbc = NULL;
+}
+
 SheetControlGUI *
 sheet_control_gui_new (SheetView *sv, WorkbookControlGUI *wbcg)
 {
@@ -1101,6 +1108,10 @@ sheet_control_gui_new (SheetView *sv, WorkbookControlGUI *wbcg)
 	scg->wbcg = wbcg;
 	scg->sheet_control.wbc = WORKBOOK_CONTROL (wbcg);
 
+	g_object_weak_ref (G_OBJECT (wbcg), 
+		(GWeakNotify) cb_wbc_destroyed, 
+		scg);
+
 	scg->active_panes = 1;
 	scg->pane [0].is_active = FALSE;
 	scg->pane [1].is_active = FALSE;
@@ -1254,6 +1265,11 @@ scg_finalize (GObject *object)
 		scg->table =NULL;
 	}
 
+	if (scg->wbcg != NULL)
+		g_object_weak_unref (G_OBJECT (scg->wbcg), 
+			(GWeakNotify) cb_wbc_destroyed, 
+			scg);
+
 	if (G_OBJECT_CLASS (scg_parent_class)->finalize)
 		(*G_OBJECT_CLASS (scg_parent_class)->finalize)(object);
 }
@@ -1682,13 +1698,15 @@ scg_mode_edit (SheetControl *sc)
 	/* During destruction we have already been disconnected
 	 * so don't bother changing the cursor
 	 */
-	if (sc->sheet != NULL)
+	if (sc->sheet != NULL && sc->view != NULL)
 		scg_cursor_visible (scg, TRUE);
 
-	if (wbcg_edit_has_guru (scg->wbcg))
-		wbcg_edit_finish (scg->wbcg, FALSE, NULL);
-	wb_control_menu_state_update (WORKBOOK_CONTROL (scg->wbcg),
-		MS_CLIPBOARD);
+	if (scg->wbcg != NULL) {
+		if (wbcg_edit_has_guru (scg->wbcg))
+			wbcg_edit_finish (scg->wbcg, FALSE, NULL);
+		wb_control_menu_state_update (WORKBOOK_CONTROL (scg->wbcg),
+			MS_CLIPBOARD);
+	}
 }
 
 /*
@@ -1748,6 +1766,7 @@ scg_mode_create_object (SheetControlGUI *scg, SheetObject *so)
 	if (scg_mode_clear (scg)) {
 		scg->new_object = so;
 		scg_cursor_visible (scg, FALSE);
+		scg_take_focus (scg);
 		scg_set_display_cursor (scg);
 		wb_control_menu_state_update (WORKBOOK_CONTROL (scg->wbcg),
 			MS_CLIPBOARD);
@@ -1806,8 +1825,8 @@ scg_object_update_bbox (SheetControlGUI *scg, SheetObject *so,
 
 	l = scg->object_coords [0];
 	t = scg->object_coords [1];
-	r = scg->object_coords [2] + 1;
-	b = scg->object_coords [3] + 1;
+	r = scg->object_coords [2];
+	b = scg->object_coords [3];
 
 	SCG_FOREACH_PANE (scg, pane,
 		gnm_pane_object_set_bounds (pane, so, l, t, r ,b););
