@@ -425,7 +425,7 @@ stf_write_csv (GnmFileSaver const *fs, IOContext *context,
 	stf_export_options_set_quoting_mode    (config, QUOTING_MODE_AUTO);
 	stf_export_options_set_quoting_char    (config, '"');
 	stf_export_options_sheet_list_add      (config,
-		workbook_sheet_by_index	 (wb_view_workbook (wbv), 0));
+						wb_view_cur_sheet (wbv));
 	stf_export_options_set_write_callback  (config,
 		(StfEWriteFunc) stf_write_func, (gpointer) output);
 
@@ -438,16 +438,29 @@ stf_write_csv (GnmFileSaver const *fs, IOContext *context,
 static gboolean
 csv_tsv_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 {
-	/* always probe by name.  We can not really tell what encoding is in use
-	 * so its hard to spot invalid data, and we do not want stuff to just
-	 * get sucked in by default */
+	if (pl == FILE_PROBE_CONTENT) {
+		/* Rough and ready heuristic.  If the first 80 bytes have no
+		 * nuls this may be text */
+		guint8 const *header;
+		int i = 80;
+
+		if (gsf_input_seek (input, 0, G_SEEK_SET) ||
+		    NULL == (header = gsf_input_read (input, i, NULL)))
+			return FALSE;
+		while (i-- > 0)
+			if (*header++ == 0)
+				return FALSE;
+		return TRUE;
+	} else {
 	char const *name = gsf_input_name (input);
 	if (name == NULL)
 		return FALSE;
 	name = gsf_extension_pointer (name);
 	return (name != NULL &&
 		(g_ascii_strcasecmp (name, "csv") == 0 ||
-		 g_ascii_strcasecmp (name, "tsv") == 0));
+			 g_ascii_strcasecmp (name, "tsv") == 0 ||
+			 g_ascii_strcasecmp (name, "txt") == 0));
+	}
 }
 
 void
