@@ -76,6 +76,7 @@ dao_init (data_analysis_output_t *dao,
 	dao->clear_outputrange = TRUE;
 	dao->retain_format     = FALSE;
 	dao->retain_comments   = FALSE;
+	dao->put_formulas      = FALSE;
 
 	return dao;
 }
@@ -92,7 +93,7 @@ dao_init (data_analysis_output_t *dao,
 char *
 dao_range_name (data_analysis_output_t *dao)
 {
-	Range range;
+	GnmRange range;
 	range_init (&range, dao->start_col, dao->start_row,
 		    dao->start_col + dao->cols - 1, 
 		    dao->start_row + dao->rows - 1);
@@ -155,11 +156,15 @@ void
 dao_adjust (data_analysis_output_t *dao, gint cols, gint rows)
 {
 	if (dao->cols == 1 && dao->rows == 1) {
-		dao->cols = cols;
-		dao->rows = rows;
+		if (cols != -1)
+			dao->cols = cols;
+		if (rows != -1)
+			dao->rows = rows;
 	} else {
-		dao->cols = MIN (cols, dao->cols);
-		dao->rows = MIN (rows, dao->rows);
+		if (cols != -1)
+			dao->cols = MIN (cols, dao->cols);
+		if (rows != -1)
+			dao->rows = MIN (rows, dao->rows);
 	}
 }
 
@@ -183,8 +188,10 @@ dao_prepare_output (WorkbookControl *wbc, data_analysis_output_t *dao,
 
 	if (dao->type == NewSheetOutput) {
 		Workbook *wb = wb_control_workbook (dao->wbc);
-		unique_name = workbook_sheet_get_free_name (wb, name, FALSE,
-							    FALSE);
+		char *name_with_counter = g_strdup_printf ("%s (1)", name);
+		unique_name = workbook_sheet_get_free_name 
+			(wb, name_with_counter, FALSE, TRUE);
+		g_free (name_with_counter);
 	        dao->sheet = sheet_new (wb, unique_name);
 		g_free (unique_name);
 		dao->start_col = dao->start_row = 0;
@@ -221,7 +228,7 @@ gboolean
 dao_format_output (data_analysis_output_t *dao, char const *cmd)
 {
 	int clear_flags = 0;
-	Range range;
+	GnmRange range;
 
 	range_init (&range, dao->start_col, dao->start_row,
 		    dao->start_col + dao->cols - 1, 
@@ -229,7 +236,7 @@ dao_format_output (data_analysis_output_t *dao, char const *cmd)
 
 	if (dao->type == RangeOutput
 	    && sheet_range_splits_region (dao->sheet, &range, NULL,
-					  COMMAND_CONTEXT (dao->wbc), cmd))
+					  GNM_CMD_CONTEXT (dao->wbc), cmd))
 		return TRUE;
 
 	if (dao->clear_outputrange)
@@ -243,10 +250,37 @@ dao_format_output (data_analysis_output_t *dao, char const *cmd)
 			    range.start.col, range.start.row,
 			    range.end.col, range.end.row,
 			    clear_flags | CLEAR_NOCHECKARRAY | CLEAR_MERGES,
-			    COMMAND_CONTEXT (dao->wbc));
+			    GNM_CMD_CONTEXT (dao->wbc));
 	return FALSE;
 }
 
+void 
+dao_set_cell_expr (data_analysis_output_t *dao, int col, int row,
+		   GnmExpr const *expr)
+{
+        GnmCell *cell;
+
+	col += dao->offset_col;
+	row += dao->offset_row;
+
+	/* Check that the output is in the given range, but allow singletons
+	 * to expand
+	 */
+	if (dao->type == RangeOutput &&
+	    (dao->cols > 1 || dao->rows > 1) &&
+	    (col >= dao->cols || row >= dao->rows))
+	        return;
+
+	col += dao->start_col;
+	row += dao->start_row;
+	if (col >= SHEET_MAX_COLS || row >= SHEET_MAX_ROWS)
+		return;
+
+	cell = sheet_cell_fetch (dao->sheet, col, row);
+	cell_set_expr (cell, expr);
+}
+
+
 /**
  * dao_set_cell_value:
  * @dao:
@@ -261,10 +295,11 @@ dao_format_output (data_analysis_output_t *dao, char const *cmd)
  * 
  *
  **/
+
 void
-dao_set_cell_value (data_analysis_output_t *dao, int col, int row, Value *v)
+dao_set_cell_value (data_analysis_output_t *dao, int col, int row, GnmValue *v)
 {
-        Cell *cell;
+        GnmCell *cell;
 
 	col += dao->offset_col;
 	row += dao->offset_row;
@@ -288,10 +323,9 @@ dao_set_cell_value (data_analysis_output_t *dao, int col, int row, Value *v)
 
 	cell = sheet_cell_fetch (dao->sheet, col, row);
 
-	sheet_cell_set_value (cell, v);
+	sheet_cell_set_value (cell, v);       
 }
 
-
 /**
  * dao_set_cell:
  * @dao:
@@ -431,8 +465,8 @@ void
 dao_set_cell_comment (data_analysis_output_t *dao, int col, int row,
 		      const char *comment)
 {
-	CellPos pos;
-	const char *author = NULL;
+	GnmCellPos pos;
+	char const *author = NULL;
 
 	/* Check that the output is in the given range, but allow singletons
 	 * to expand
@@ -529,9 +563,9 @@ dao_autofit_columns (data_analysis_output_t *dao)
  **/
 static void
 dao_set_style (data_analysis_output_t *dao, int col1, int row1,
-	      int col2, int row2, MStyle *mstyle)
+	      int col2, int row2, GnmStyle *mstyle)
 {
-	Range  range;
+	GnmRange  range;
 
 	range.start.col = col1 + dao->start_col + dao->offset_col;
 	range.start.row = row1 + dao->start_row + dao->offset_row;
@@ -543,10 +577,14 @@ dao_set_style (data_analysis_output_t *dao, int col1, int row1,
 	if (range.end.row > dao->start_row + dao->rows)
 		range.end.row = dao->start_row + dao->rows;
 
-	if (range.end.col < range.start.col)
+	if (range.end.col < range.start.col) {
+		mstyle_unref (mstyle);
 		return;
-	if (range.end.row < range.start.row)
+	}
+	if (range.end.row < range.start.row) {
+		mstyle_unref (mstyle);
 		return;
+	}
 
 	sheet_style_apply_range (dao->sheet, &range, mstyle);
 }
@@ -567,8 +605,8 @@ void
 dao_set_bold (data_analysis_output_t *dao, int col1, int row1,
 	      int col2, int row2)
 {
-	MStyle *mstyle = mstyle_new ();
-	Range  range;
+	GnmStyle *mstyle = mstyle_new ();
+	GnmRange  range;
 
 	range.start.col = col1 + dao->start_col;
 	range.start.row = row1 + dao->start_row;
@@ -595,8 +633,8 @@ void
 dao_set_underlined (data_analysis_output_t *dao, int col1, int row1,
 		    int col2, int row2)
 {
-	MStyle *mstyle = mstyle_new ();
-	Range  range;
+	GnmStyle *mstyle = mstyle_new ();
+	GnmRange  range;
 
 	range.start.col = col1 + dao->start_col;
 	range.start.row = row1 + dao->start_row;
@@ -623,11 +661,10 @@ void
 dao_set_italic (data_analysis_output_t *dao, int col1, int row1,
 		int col2, int row2)
 {
-	MStyle *mstyle = mstyle_new ();
+	GnmStyle *mstyle = mstyle_new ();
 
 	mstyle_set_font_italic (mstyle, TRUE);
-	dao_set_style (dao, col1 + dao->start_col, row1 + dao->start_row,
-		       col2 + dao->start_col, row2 + dao->start_row, mstyle);
+	dao_set_style (dao, col1, row1, col2, row2, mstyle);
 }
 
 /**
@@ -646,11 +683,39 @@ void
 dao_set_percent (data_analysis_output_t *dao, int col1, int row1,
 		 int col2, int row2)
 {
-	MStyle *mstyle = mstyle_new ();
+	GnmStyle *mstyle = mstyle_new ();
+	GnmFormat *style_format = NULL;
 
-	mstyle_set_format_text (mstyle, "0.00%");
-	dao_set_style (dao, col1 + dao->start_col, row1 + dao->start_row,
-		       col2 + dao->start_col, row2 + dao->start_row, mstyle);
+	style_format = style_format_default_percentage ();
+	mstyle_set_format (mstyle, style_format);
+
+	dao_set_style (dao, col1, row1, col2, row2, mstyle);
+}
+
+/**
+ * dao_set_date:
+ * @dao:
+ * @col1:
+ * @row1:
+ * @col2:
+ * @row2:
+ *
+ * set the given cell range to date format
+ * 
+ *
+ **/
+void
+dao_set_date (data_analysis_output_t *dao, int col1, int row1,
+		 int col2, int row2)
+{
+	GnmStyle *mstyle = mstyle_new ();
+	GnmFormat *style_format = NULL;
+
+	style_format = style_format_default_date ();
+	mstyle_set_format (mstyle, style_format);
+
+	dao_set_style (dao, col1, row1,
+		       col2, row2, mstyle);
 }
 
 /**
@@ -668,16 +733,16 @@ dao_set_percent (data_analysis_output_t *dao, int col1, int row1,
 void
 dao_set_colors (data_analysis_output_t *dao, int col1, int row1,
 		int col2, int row2,
-		StyleColor *fore, StyleColor *back)
+		GnmColor *fore, GnmColor *back)
 {
-	MStyle *mstyle;
+	GnmStyle *mstyle;
 
 	mstyle = mstyle_new ();
 	mstyle_set_color (mstyle, MSTYLE_COLOR_FORE, fore);
 	mstyle_set_color (mstyle, MSTYLE_COLOR_BACK, back);
 	mstyle_set_pattern (mstyle, 1);
-	dao_set_style (dao, col1 + dao->start_col, row1 + dao->start_row,
-		       col2 + dao->start_col, row2 + dao->start_row, mstyle);
+	dao_set_style (dao, col1, row1,
+		       col2, row2, mstyle);
 }
 
 /**
@@ -697,13 +762,12 @@ dao_set_align (data_analysis_output_t *dao, int col1, int row1,
 	       int col2, int row2,
 	       StyleHAlignFlags align_h, StyleVAlignFlags align_v)
 {
-	MStyle *mstyle;
+	GnmStyle *mstyle;
 
 	mstyle = mstyle_new ();
 	mstyle_set_align_h (mstyle, align_h);
 	mstyle_set_align_v (mstyle, align_v);
-	dao_set_style (dao, col1 + dao->start_col, row1 + dao->start_row,
-		       col2 + dao->start_col, row2 + dao->start_row, mstyle);
+	dao_set_style (dao, col1, row1, col2, row2, mstyle);
 }
 
 
@@ -789,7 +853,8 @@ void
 dao_write_header (data_analysis_output_t *dao, const gchar *toolname,
 		  const gchar *title, Sheet *sheet)
 {
-	GString   *buf;
+	GString *buf;
+	char *filename_utf8;
 
 	buf = g_string_new (NULL);
 	g_string_append_printf (buf, "%s %s %s %s", 
@@ -798,11 +863,13 @@ dao_write_header (data_analysis_output_t *dao, const gchar *toolname,
 	g_string_free (buf, FALSE);
 
 	buf = g_string_new (NULL);
+	filename_utf8 = workbook_get_filename_utf8 (sheet->workbook, FALSE);
 	g_string_append_printf (buf, "%s [%s]%s", _("Worksheet:"),
-		workbook_get_filename (sheet->workbook),
+		filename_utf8,
 		sheet->name_quoted);
 	dao_set_cell (dao, 0, 1, buf->str);
 	g_string_free (buf, FALSE);
+	g_free (filename_utf8);
 
 	buf = g_string_new (NULL);
 	g_string_append (buf, _("Report Created: "));
@@ -823,7 +890,7 @@ dao_find_name (Sheet *sheet, int col, int row)
         int         col_n, row_n;
 
 	for (col_n = col - 1; col_n >= 0; col_n--) {
-	        Cell *cell = sheet_cell_get (sheet, col_n, row);
+	        GnmCell *cell = sheet_cell_get (sheet, col_n, row);
 		if (cell && !VALUE_IS_NUMBER (cell->value)) {
 			col_str = value_peek_string (cell->value);
 		        break;
@@ -831,7 +898,7 @@ dao_find_name (Sheet *sheet, int col, int row)
 	}
 
 	for (row_n = row - 1; row_n >= 0; row_n--) {
-	        Cell *cell = sheet_cell_get (sheet, col, row_n);
+	        GnmCell *cell = sheet_cell_get (sheet, col, row_n);
 		if (cell && !VALUE_IS_NUMBER (cell->value)) {
 			row_str = value_peek_string (cell->value);
 		        break;
@@ -854,3 +921,44 @@ dao_find_name (Sheet *sheet, int col, int row)
 
 	return str;
 }
+
+gboolean 
+dao_put_formulas (data_analysis_output_t *dao)
+{
+	g_return_val_if_fail (dao != NULL, FALSE);
+	return dao->put_formulas;
+}
+
+void 
+dao_convert_to_values (data_analysis_output_t *dao)
+{
+	int row, col;
+
+	if (dao->put_formulas)
+		return;
+
+	workbook_recalc (dao->sheet->workbook);
+	for (row = 0; row < dao->rows; row++) {
+		for (col = 0; col < dao->cols; col++) {
+			GnmCell *cell = sheet_cell_get (dao->sheet, 
+				dao->start_col + col, dao->start_row + row);
+			if (cell != NULL && cell_has_expr (cell))
+				cell_convert_expr_to_value (cell);
+		}
+	}
+}
+
+void
+dao_redraw_respan (data_analysis_output_t *dao)
+{
+	GnmRange r;
+
+	range_init (&r, dao->start_col, dao->start_row, 
+		    dao->start_col + dao->cols - 1, 
+		    dao->start_row + dao->rows - 1);
+	sheet_range_calc_spans (dao->sheet, &r, 
+				SPANCALC_RESIZE | SPANCALC_RENDER);
+	sheet_region_queue_recalc (dao->sheet, &r);
+	dao_convert_to_values (dao);	
+	sheet_redraw_range (dao->sheet, &r);
+}
