@@ -52,6 +52,8 @@
 #include <gsf/gsf-input-stdio.h>
 #include <gsf/gsf-output-stdio.h>
 #include <gsf/gsf-utils.h>
+#include <gsf-gnome/gsf-input-gnomevfs.h>
+#include <gsf-gnome/gsf-output-gnomevfs.h>
 
 #include <gsf/gsf-impl-utils.h>
 #include <locale.h>
@@ -264,7 +266,7 @@ wb_view_selection_desc (WorkbookView *wbv, gboolean use_pos,
 		     range_equal (r, m))) {
 			sel_descr = sheet_names_check (sv->sheet, r);
 			if (sel_descr == NULL)
-				sel_descr = cellpos_as_string (&r->start);
+				sel_descr = cellpos_as_string (&sv->edit_pos);
 		} else {
 			int rows = r->end.row - r->start.row + 1;
 			int cols = r->end.col - r->start.col + 1;
@@ -569,9 +571,20 @@ wbv_save_to_file (WorkbookView *wbv, GnmFileSaver const *fs,
 
 	if (filename_utf8) {
 		GError *err = NULL;
-		GsfOutputStdio *output;
+		GsfOutput   *output = NULL;
+		GnomeVFSURI *uri = gnome_vfs_uri_new (filename);
+
+		/* cheesy mechanism to prefer stdio */
+		if (uri != NULL && uri->method_string != NULL &&
+		    0 != strcmp ("file", uri->method_string)) {
+			output = (GsfOutput *)gsf_output_gnomevfs_new (filename, &err);
+		} else {
+			output = (GsfOutput *)gsf_output_stdio_new (filename, &err);
+		}
+
+		if (uri != NULL)
+			gnome_vfs_uri_unref (uri);
 
-		output = gsf_output_stdio_new (filename, &err);
 		if (output == NULL) {
 			char *str = g_strdup_printf (_("Can't open '%s' for writing: %s"),
 						     filename_utf8, err->message);
@@ -741,8 +754,7 @@ wb_view_sendto (WorkbookView *wbv, GnmCmdContext *context)
 
 #define GNM_SEND_DIR	".gnm-sendto-"
 #ifdef HAVE_MKDTEMP
-		template = g_build_path (G_DIR_SEPARATOR_S, 
-					 g_get_tmp_dir (),
+		template = g_build_filename (g_get_tmp_dir (),
 					 GNM_SEND_DIR "XXXXXX", NULL);
 		mkdtemp (template);
 #else
@@ -752,9 +764,7 @@ wb_view_sendto (WorkbookView *wbv, GnmCmdContext *context)
 				 (long)getpid (),
 				 (int)(1e8 * random_01 ()));
 
-			template = g_build_path (G_DIR_SEPARATOR_S, 
-						 g_get_tmp_dir (),
-						 dirname, NULL);
+			template = g_build_filename (g_get_tmp_dir (), dirname, NULL);
 			if (mkdir (template, 0700) == 0)
 				break;
 
@@ -772,8 +782,7 @@ wb_view_sendto (WorkbookView *wbv, GnmCmdContext *context)
 		}
 #endif
 
-		full_name = g_build_path (G_DIR_SEPARATOR_S, 
-			template, basename, NULL);
+		full_name = g_build_filename (template, basename, NULL);
 		g_free (basename);
 
 		wbv_save_to_file (wbv, fs, full_name, io_context);
@@ -932,7 +941,16 @@ wb_view_new_from_file (char const *filename,
 		in_mem = gsf_input_mmap_new (filename, NULL);
 		if (in_mem == NULL) {
 			in_stdio = gsf_input_stdio_new (filename, &err);
-			if (in_stdio != NULL)
+			if (in_stdio == NULL) {
+				GsfInputGnomeVFS *in_vfs;
+				
+				g_error_free (err);
+				err = NULL;
+
+				in_vfs = gsf_input_gnomevfs_new (filename, &err);
+				if (in_vfs != NULL)
+					input = GSF_INPUT (in_vfs);
+			} else
 				input = GSF_INPUT (in_stdio);
 		} else
 			input = GSF_INPUT (in_mem);
